﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;
using System.Drawing;
using System.Reflection;
using System.Diagnostics;

namespace Post8316
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();
        }
        ClassBreakStyle classBreakStyle;
        private void Window_Loaded(object sender, RoutedEventArgs e)
        {

            wpfMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
            wpfMap1.CurrentExtent = new RectangleShape(-140, 60, 140, -60);
            wpfMap1.MapUnit = GeographyUnit.DecimalDegree;

            classBreakStyle = new ClassBreakStyle("POP_CNTRY");
            classBreakStyle.ClassBreaks.Add(new ClassBreak(double.MinValue, AreaStyles.Grass1));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(1000000, AreaStyles.Evergreen2));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(10000000, AreaStyles.Evergreen1));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(50000000, AreaStyles.Crop1));
            classBreakStyle.ClassBreaks.Add(new ClassBreak(100000000, AreaStyles.Forest1));

            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"..\..\Data\Countries02.shp");
            worldLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(AreaStyles.Country1);
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            worldLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(classBreakStyle);

            LayerOverlay overlay = new LayerOverlay();
            overlay.Layers.Add("worldLayer", worldLayer);
            wpfMap1.Overlays.Add("overlay", overlay);

            wpfMap1.Refresh();

            CreateLegendImage(classBreakStyle);
            BindImages();
        }

        private void BindImages()
        {
            string filePath = Process.GetCurrentProcess().MainModule.FileName;
            string folder = System.IO.Path.GetDirectoryName(filePath);
            image1.Source = new BitmapImage(new Uri(folder + "\\" + "LegendImage\\-1.79769313486232E+308.jpg"));
            image2.Source = new BitmapImage(new Uri(folder + "\\" + "LegendImage\\1000000.jpg"));
            image3.Source = new BitmapImage(new Uri(folder + "\\" + "LegendImage\\10000000.jpg"));
            image4.Source = new BitmapImage(new Uri(folder + "\\" + "LegendImage\\50000000.jpg"));
            image5.Source = new BitmapImage(new Uri(folder + "\\" + "LegendImage\\100000000.jpg"));
        }

        private void CreateLegendImage(ClassBreakStyle classBreakStyle)
        {
            GdiPlusGeoCanvas canvas = new GdiPlusGeoCanvas();

            foreach (ClassBreak classBreak in classBreakStyle.ClassBreaks)
            {
                using (Bitmap bitmap = new Bitmap(40, 20))
                {
                    string filePath = string.Format(@".\LegendImage\{0}.jpg", classBreak.Value);
                    canvas.BeginDrawing(bitmap, new RectangleShape(0, bitmap.Width, bitmap.Height, 0), GeographyUnit.DecimalDegree);
                    classBreak.DefaultAreaStyle.DrawSample(canvas);
                    canvas.DrawScreenImageWithoutScaling(bitmap, 0, 0, DrawingLevel.LevelOne, 0, 0, 0);
                    bitmap.Save(filePath);
                }
            }
        }
    }
}
